summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmrawedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmrawedit.h')
-rw-r--r--kpovmodeler/pmrawedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmrawedit.h b/kpovmodeler/pmrawedit.h
index f3ba740d..620e6b09 100644
--- a/kpovmodeler/pmrawedit.h
+++ b/kpovmodeler/pmrawedit.h
@@ -39,9 +39,9 @@ class PMRawEdit : public PMNamedObjectEdit
typedef PMNamedObjectEdit Base;
public:
/**
* Creates a PMRawEdit with tqparent and name
*/
- PMRawEdit( TQWidget* tqparent, const char* name = 0 );
+ PMRawEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,9 +39,9 @@ class PMRawEdit : public PMNamedObjectEdit
public:
/**
- * Creates a PMRawEdit with tqparent and name
+ * Creates a PMRawEdit with parent and name
*/